## Hivemind
[![Build status](https://circleci.com/gh/learning-at-home/hivemind.svg?style=shield)](https://circleci.com/gh/learning-at-home/hivemind)
[![Documentation Status](https://readthedocs.org/projects/learning-at-home/badge/?version=latest)](https://learning-at-home.readthedocs.io/en/latest/?badge=latest)

A library to train large neural networks across the internet. Imagine training one huge transformer
  on thousands of computers from universities, companies, and volunteers.

![img](https://i.imgur.com/GPxolxb.gif)

##### Links:
 * What is hivemind all about? Here's a [3-minute read](https://learning-at-home.github.io) or a [full paper](https://arxiv.org/abs/2002.04013)
 * [Quickstart tutorial](https://learning-at-home.readthedocs.io/en/latest/user/quickstart.html) - install hivemind, 
    set up a server and train experts  
 * Documentation & guides: [learning-at-home.readthedocs.io](https://learning-at-home.readthedocs.io)
 * [Contributor's guide](https://learning-at-home.readthedocs.io/en/latest/user/contributing.html): best practices, tests and performance benchmarks
 * [Related](https://learning-at-home.readthedocs.io/en/latest/user/acknowledgements.html) projects and acknowledgements
